==> tecfy_core_package-1.2.6.tar.gz: lib/models/entity/property_dynamic.model.dart <==
part of tecfy_core_client_package;

class PropertyDynamic extends Property {
  late String dynamicPropertiesField;
  
  PropertyDynamic(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      required this.dynamicPropertiesField})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Dynamic,
            valueType: ValueTypes.ObjectArray,
            isRequired: isRequired);

  PropertyDynamic.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    dynamicPropertiesField = row['dynamicPropertiesField'] ?? '';
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);

    //return Text(data[dbName]?.toString()?.substring(0,10) ?? '',style:TextStyle(fontSize: size,color:color));
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    return '';
  }

  static String getDisplayTextValue(dynamic val, String? format) {
    return '';
  }

  static Widget getDisplay(dynamic value,
      [String? format, Color color = Colors.black, double size = 10]) {
    return Text(getDisplayTextValue(value, format),
        style: TextStyle(fontSize: size, color: color));
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    // if (isTodayByDefault) {
    //   data[dbName] = DateTime.now().toUtc();
    //   return true;
    // }
    return false;
  }
}

==> tecfy_core_package-1.2.7.tar.gz: lib/models/entity/property_dynamic.model.dart <==
part of tecfy_core_client_package;

class PropertyDynamic extends Property {
  late String dynamicPropertiesField;

  PropertyDynamic(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      required this.dynamicPropertiesField})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Dynamic,
            valueType: ValueTypes.ObjectArray,
            isRequired: isRequired);

  PropertyDynamic.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    dynamicPropertiesField = row['dynamicPropertiesField'] ?? '';
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return SelectableText(getDisplayText(data), style: textStyle);

    //return Text(data[dbName]?.toString()?.substring(0,10) ?? '',style:TextStyle(fontSize: size,color:color));
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    try {
      var jsn = jsonDecode(data[dbName]);
      var result = '';
      for (var k in jsn.keys) {
        result += '$k : ${jsn[k]} \n';
      }
      return result;
    } catch (e) {}
    return data[dbName]?.toString() ?? '';
  }

  static String getDisplayTextValue(dynamic val, String? format) {
    try {
      var jsn = jsonDecode(val);
      var result = '';
      for (var k in jsn.keys) {
        result += '$k : ${jsn[k]} \n';
      }
      return result;
    } catch (e) {}
    return val?.toString() ?? '';
  }

  static Widget getDisplay(dynamic value,
      [String? format, Color color = Colors.black, double size = 10]) {
    return Text(getDisplayTextValue(value, format),
        style: TextStyle(fontSize: size, color: color));
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    // if (isTodayByDefault) {
    //   data[dbName] = DateTime.now().toUtc();
    //   return true;
    // }
    return false;
  }
}
